@@ -1,4 +1,5 @@
 import os
+from os.path import exists
 import pkg_resources
 import json
 from typing import Any, Dict
@@ -20,13 +21,13 @@ def read_config() -> Dict[str, Any]:
         return json.load(f)
 
 def write_config(config: Dict[str, Any]) -> None:
-    with open(CONFIG_FILE, 'w') as f:
+    with open(CONFIG_FILE, 'x') as f:
         json.dump(config, f)
 
 def initialize() -> None:
-    try:
+    if exists(CONFIG_FILE):
         config = read_config()
-    except FileNotFoundError:
+    else:
         bblib = os.getenv("bblib")
         if bblib:
             library = bblib
@@ -36,8 +37,12 @@ def initialize() -> None:
             'library': library,
         }
         write_config(config)
-        os.system(f"cd {library}; git init")
-        os.system(f"cd {library}; mkdir -p cache")
-        print(f"Initialized BioBricks library to {library}.")
     globals().update(config)
-    
\ No newline at end of file
+    if not exists(library):
+        os.system(f"mkdir -p {library}")
+    if not exists(library+"/.git"):
+        os.system(f"cd {library}; git init")
+    if not exists(library+"/cache"):
+        os.system(f"cd {library}; mkdir -p cache")
+    print(f"Initialized BioBricks library to {library}.")
+
